==> nest-infrastructure-middleware-rabbitmq-3.5.3.0-20251212.071510-7-sources.jar: com/digiwin/dap/nest/infrastructure/middleware/rabbitmq/context/PinpointTraceContextLink.java <==
package com.digiwin.dap.nest.infrastructure.middleware.rabbitmq.context;

import com.digiwin.dap.nest.kernel.core.context.DwMapContextLink;
import com.digiwin.dap.nest.kernel.core.context.biz.DwCoreContextEntity;
import com.digiwin.dap.nest.kernel.core.dapper.log.JaMDC;
import com.digiwin.dap.nest.kernel.core.util.DwStringUtil;

import java.util.Map;

/**
 * 兼容
 *
 * @author chenjian
 * @since 2024年06月04日 19:27:44
 */
public class PinpointTraceContextLink implements DwMapContextLink<DwCoreContextEntity> {

    public static final String PinpointTraceIDKey = "Pinpoint-TraceID";
    public static final String PinpointSpanIDKey = "Pinpoint-pSpanID";

    @Override
    public void inherit(Map<String, String> source, DwCoreContextEntity target) {
        String traceId = source.get(JaMDC.KeyTraceId);
        if (DwStringUtil.isEmpty(traceId)) {
            traceId = source.get(PinpointTraceIDKey);
            if (DwStringUtil.isNotEmpty(traceId)) {
                source.put(JaMDC.KeyTraceId, traceId);
            }
        }
        JaMDC.put(DwStringUtil.isEmpty(traceId) ? JaMDC.createTraceId() : traceId);

        String parentSpanId = source.get(JaMDC.KeyParentSpanId);
        if (DwStringUtil.isEmpty(parentSpanId)) {
            parentSpanId = source.get(PinpointSpanIDKey);
            if (DwStringUtil.isNotEmpty(parentSpanId)) {
                source.put(JaMDC.KeyTraceId, parentSpanId);
                JaMDC.putParentSpanId(parentSpanId);
            }
        }
    }

    @Override
    public void transmit(DwCoreContextEntity source, Map<String, String> target) {
        // Do nothing
    }

    @Override
    public int order() {
        return -1000;
    }
}

==> nest-infrastructure-middleware-rabbitmq-5.5.0.1000-20251217.112142-5-sources.jar: com/digiwin/dap/nest/infrastructure/middleware/rabbitmq/context/PinpointTraceContextLink.java <==
package com.digiwin.dap.nest.infrastructure.middleware.rabbitmq.context;

import com.digiwin.dap.nest.kernel.core.context.DwMapContextLink;
import com.digiwin.dap.nest.kernel.core.context.biz.DwCoreContextEntity;
import com.digiwin.dap.nest.kernel.core.dapper.log.DwMDC;
import com.digiwin.dap.nest.kernel.core.util.DwStringUtil;

import java.util.Map;

/**
 * 兼容
 *
 * @author chenjian
 * @since 2024年06月04日 19:27:44
 */
public class PinpointTraceContextLink implements DwMapContextLink<DwCoreContextEntity> {

    public static final String PinpointTraceIDKey = "Pinpoint-TraceID";
    public static final String PinpointSpanIDKey = "Pinpoint-pSpanID";

    @Override
    public void inherit(Map<String, String> source, DwCoreContextEntity target) {
        String traceId = source.get(DwMDC.KeyTraceId);
        if (DwStringUtil.isEmpty(traceId)) {
            traceId = source.get(PinpointTraceIDKey);
            if (DwStringUtil.isNotEmpty(traceId)) {
                source.put(DwMDC.KeyTraceId, traceId);
            }
        }
        DwMDC.put(DwStringUtil.isEmpty(traceId) ? DwMDC.createTraceId() : traceId);

        String parentSpanId = source.get(DwMDC.KeyParentSpanId);
        if (DwStringUtil.isEmpty(parentSpanId)) {
            parentSpanId = source.get(PinpointSpanIDKey);
            if (DwStringUtil.isNotEmpty(parentSpanId)) {
                source.put(DwMDC.KeyTraceId, parentSpanId);
                DwMDC.putParentSpanId(parentSpanId);
            }
        }
    }

    @Override
    public void transmit(DwCoreContextEntity source, Map<String, String> target) {
        // Do nothing
    }

    @Override
    public int order() {
        return -1000;
    }
}
